#!/bin/bash

# Installing and unistalling i360.so for native phps

I360_PREFIX="/usr/share/i360-php"

CMD=${1}
PHP_PATHS=${2:-/usr/bin/php[0-9]*}

function install_i360()
{
        PHP_EXE=$1
        if [ ! -f "${PHP_EXE}" ]; then
            return
        fi
        LIBS=""
        if [ "$(uname -m)" == "x86_64" ]; then
            LIBS="/x86_64-linux-gnu"
        fi
        EXT_DIR=$(${PHP_EXE} -i | grep -e "^extension_dir" | cut -d"=" -f2 | tr ">" " " | sed 's/^ *//;s/ *$//')
        VERS=$(${PHP_EXE} --version | head -n1 | cut -d' ' -f2 | cut -c 1,3)
        if [ -z "${EXT_DIR}" ] || [ -z "${VERS}" ]; then
            return
        fi

        MODULE_DIR="${I360_PREFIX}/php${VERS}/usr/lib${LIBS}/php/modules"
        MODULE_I360="${MODULE_DIR}/i360.so"
        MODULE_INI="${I360_PREFIX}/php${VERS}/etc/php.d.all/i360.ini"
        CAGEFSCTL=/usr/sbin/cagefsctl

        if [ -f "${MODULE_I360}" ]; then
            rm -f "${EXT_DIR}/i360.so"
            cp "${MODULE_I360}" "${EXT_DIR}"
            if [ -e "${CAGEFSCTL}" ] && [ -e "$EXT_DIR/i360.so" ]; then
                echo "$EXT_DIR/i360.so" | ${CAGEFSCTL} --update-list
            fi
        fi

        PHP_DIR=$(dirname $(dirname $(${PHP_EXE} -i | grep "Scan this dir for additional .ini files" | cut -d"=" -f2 | tr ">" " " | sed 's/^ *//;s/ *$//')))
        if [ -e "${MODULE_INI}" ] && [ -e "${PHP_DIR}/mods-available" ]; then
            cp "${MODULE_INI}" "${PHP_DIR}/mods-available"
        fi

        PHPENMOD=/usr/sbin/phpenmod
        PHPENMOD_VERS=$(${PHP_EXE} --version | head -n1 | cut -d' ' -f2 | cut -c 1,2,3)
        if [ -e "${PHPENMOD}" ]; then
            ${PHPENMOD} -v "${PHPENMOD_VERS}" i360
        fi
}

function uninstall_i360()
{
        PHP_EXE=$1
        if [ ! -f "${PHP_EXE}" ]; then
            return
        fi

        INI_DIR=$(${PHP_EXE} -i | grep "Scan this dir for additional .ini files" | cut -d"=" -f2 | tr ">" " " | sed 's/^ *//;s/ *$//')
        if [ -n "${INI_DIR}" ] && [ -e "${INI_DIR}" ]; then
            PHPDISMOD=/usr/sbin/phpdismod
            PHPDISMOD_VERS=$(${PHP_EXE} --version | head -n1 | cut -d' ' -f2 | cut -c 1,2,3)
            if [ -e "${PHPDISMOD}" ];then
                ${PHPDISMOD} -v "${PHPDISMOD_VERS}" i360
            fi

            PHP_DIR=$(dirname $(dirname "${INI_DIR}"))
            while read -r ini_name; do
                IS_I360=$(echo "${PHP_DIR}/mods-available/${ini_name}" | grep "i360.ini" | cat)
                if [ -n "${IS_I360}" ];then
                    rm -f "${PHP_DIR}/mods-available/${ini_name}"
                fi
            done << EOF
"$(ls -1 "${PHP_DIR}/mods-available/")"
EOF
        fi

        EXT_DIR=$(${PHP_EXE} -i | grep -e "^extension_dir" | cut -d"=" -f2 | tr ">" " " | sed 's/^ *//;s/ *$//')
        if [ -f "${EXT_DIR}/i360.so" ]; then
            rm -f "${EXT_DIR}/i360.so"
        fi
}

if [ "$CMD" == "--install-i360" ]; then
    for path in $PHP_PATHS
        do install_i360 "${path}"
    done
elif [ "$CMD" == "--uninstall-i360" ]; then
    for path in $PHP_PATHS
        do uninstall_i360 "${path}"
    done
fi
